@@ -47,7 +47,7 @@ Will generate random date when you call any subrotine on it.  This module is ins
                     }
     );
 
-    Values in the array will be evaluated. You can use rand_ functions from Data::Random to generate your values.
+    Values in the array will be evaluated. You can use rand_ functions from Data::Random to generate your values.. presets queries have preference over presets_catalog quieres.
 
 
 =head3 presets_catalog
@@ -84,7 +84,8 @@ package SQL::Bibliosoph::Sims; {
     use Carp;
     use Data::Dumper;
 
-    use vars qw($AUTOLOAD);    
+	use vars qw($VERSION );
+	$VERSION = "1.8";
 
     use SQL::Bibliosoph::CatalogFile;
 
@@ -101,19 +102,21 @@ package SQL::Bibliosoph::Sims; {
         my ($self) = @_;
         my $qs;
 
+        my $file = $presets_catalog[$$self];
+        if ($file) {
+
+            die "$file: $!" if ! -e $file;
+
+            my  $qs = SQL::Bibliosoph::CatalogFile->new( file => $file )->read();
+            $self->create_presets($qs); 
+        }
+
 
         if (my $qs = $presets[$$self]) {
             $self->create_presets($qs);
         }
 
-        my $file = $presets_catalog[$$self];
-        if ($file) {
 
-            die $! if ! -e $file;
-
-            my  $qs = SQL::Bibliosoph::CatalogFile->new( file => $file )->read();
-            $self->create_presets($qs); 
-        }
 
         return $self;
     }
@@ -126,7 +129,6 @@ package SQL::Bibliosoph::Sims; {
 
         foreach my $name ( keys %$qs ) {
             my $value = $qs->{$name};
-print STDERR "VALUE IS $value\n\n";
 
             # Is this a refence?
             *{__PACKAGE__.'::'.$name} = sub {
